@@ -17,6 +17,6 @@
 #define FREERDP_VENDOR_STRING "FreeRDP"
 #define FREERDP_PRODUCT_STRING "FreeRDP"
 
-#define FREERDP_PROXY_PLUGINDIR "/usr/obj/ports/freerdp-2.10.0/build-arm/server/proxy/plugins"
+#define FREERDP_PROXY_PLUGINDIR "/local/pobj/freerdp-2.11.2/build-riscv64/server/proxy/plugins"
 
 #endif /* FREERDP_BUILD_CONFIG_H */
